summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/com/jogamp/opencl/BuildProgramCallback.java (renamed from src/com/mbien/opencl/BuildProgramCallback.java)2
-rw-r--r--src/com/jogamp/opencl/CLBuffer.java (renamed from src/com/mbien/opencl/CLBuffer.java)4
-rw-r--r--src/com/jogamp/opencl/CLCommandQueue.java (renamed from src/com/mbien/opencl/CLCommandQueue.java)18
-rw-r--r--src/com/jogamp/opencl/CLContext.java (renamed from src/com/mbien/opencl/CLContext.java)14
-rw-r--r--src/com/jogamp/opencl/CLDevice.java (renamed from src/com/mbien/opencl/CLDevice.java)14
-rw-r--r--src/com/jogamp/opencl/CLEvent.java (renamed from src/com/mbien/opencl/CLEvent.java)10
-rw-r--r--src/com/jogamp/opencl/CLEventList.java (renamed from src/com/mbien/opencl/CLEventList.java)2
-rw-r--r--src/com/jogamp/opencl/CLException.java (renamed from src/com/mbien/opencl/CLException.java)4
-rw-r--r--src/com/jogamp/opencl/CLImage.java (renamed from src/com/mbien/opencl/CLImage.java)4
-rw-r--r--src/com/jogamp/opencl/CLImage2d.java (renamed from src/com/mbien/opencl/CLImage2d.java)4
-rw-r--r--src/com/jogamp/opencl/CLImage3d.java (renamed from src/com/mbien/opencl/CLImage3d.java)6
-rw-r--r--src/com/jogamp/opencl/CLImageFormat.java (renamed from src/com/mbien/opencl/CLImageFormat.java)6
-rw-r--r--src/com/jogamp/opencl/CLInfoAccessor.java (renamed from src/com/mbien/opencl/CLInfoAccessor.java)6
-rw-r--r--src/com/jogamp/opencl/CLKernel.java (renamed from src/com/mbien/opencl/CLKernel.java)8
-rw-r--r--src/com/jogamp/opencl/CLMemory.java (renamed from src/com/mbien/opencl/CLMemory.java)14
-rw-r--r--src/com/jogamp/opencl/CLObject.java (renamed from src/com/mbien/opencl/CLObject.java)2
-rw-r--r--src/com/jogamp/opencl/CLPlatform.java (renamed from src/com/mbien/opencl/CLPlatform.java)16
-rw-r--r--src/com/jogamp/opencl/CLProgram.java (renamed from src/com/mbien/opencl/CLProgram.java)10
-rw-r--r--src/com/jogamp/opencl/CLProgramBuilder.java (renamed from src/com/mbien/opencl/CLProgramBuilder.java)10
-rw-r--r--src/com/jogamp/opencl/CLResource.java (renamed from src/com/mbien/opencl/CLResource.java)2
-rw-r--r--src/com/jogamp/opencl/CLSampler.java (renamed from src/com/mbien/opencl/CLSampler.java)12
-rw-r--r--src/com/jogamp/opencl/CreateContextCallback.java (renamed from src/com/mbien/opencl/CreateContextCallback.java)2
-rw-r--r--src/com/jogamp/opencl/Disposable.java (renamed from src/com/mbien/opencl/Disposable.java)2
-rw-r--r--src/com/jogamp/opencl/InternalBufferUtil.java (renamed from src/com/mbien/opencl/InternalBufferUtil.java)2
-rw-r--r--src/com/jogamp/opencl/NativeLibLoader.java (renamed from src/com/mbien/opencl/NativeLibLoader.java)2
-rw-r--r--src/com/jogamp/opencl/gl/CLGLBuffer.java (renamed from src/com/mbien/opencl/gl/CLGLBuffer.java)10
-rw-r--r--src/com/jogamp/opencl/gl/CLGLContext.java (renamed from src/com/mbien/opencl/gl/CLGLContext.java)12
-rw-r--r--src/com/jogamp/opencl/gl/CLGLImage2d.java (renamed from src/com/mbien/opencl/gl/CLGLImage2d.java)17
-rw-r--r--src/com/jogamp/opencl/gl/CLGLObject.java (renamed from src/com/mbien/opencl/gl/CLGLObject.java)4
-rw-r--r--src/com/jogamp/opencl/gl/CLGLTexture.java (renamed from src/com/mbien/opencl/gl/CLGLTexture.java)2
-rw-r--r--src/com/jogamp/opencl/gl/CLGLTexture2d.java (renamed from src/com/mbien/opencl/gl/CLGLTexture2d.java)14
-rw-r--r--src/com/jogamp/opencl/gl/CLGLTexture3d.java (renamed from src/com/mbien/opencl/gl/CLGLTexture3d.java)17
-rw-r--r--src/com/jogamp/opencl/util/CLBuildConfiguration.java (renamed from src/com/mbien/opencl/util/CLBuildConfiguration.java)18
-rw-r--r--src/com/jogamp/opencl/util/CLProgramConfiguration.java (renamed from src/com/mbien/opencl/util/CLProgramConfiguration.java)10
-rw-r--r--src/com/jogamp/opencl/util/CLUtil.java (renamed from src/com/mbien/opencl/util/CLUtil.java)8
-rw-r--r--src/com/jogamp/opencl/util/MultiQueueBarrier.java (renamed from src/com/mbien/opencl/util/MultiQueueBarrier.java)6
36 files changed, 145 insertions, 149 deletions
diff --git a/src/com/mbien/opencl/BuildProgramCallback.java b/src/com/jogamp/opencl/BuildProgramCallback.java
index 0b2b1b04..fe2b29b9 100644
--- a/src/com/mbien/opencl/BuildProgramCallback.java
+++ b/src/com/jogamp/opencl/BuildProgramCallback.java
@@ -1,4 +1,4 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
/**
* @author Michael Bien
diff --git a/src/com/mbien/opencl/CLBuffer.java b/src/com/jogamp/opencl/CLBuffer.java
index 2137fb91..5a2a37e7 100644
--- a/src/com/mbien/opencl/CLBuffer.java
+++ b/src/com/jogamp/opencl/CLBuffer.java
@@ -1,8 +1,8 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import java.nio.Buffer;
-import static com.mbien.opencl.CLException.*;
+import static com.jogamp.opencl.CLException.*;
/**
*
diff --git a/src/com/mbien/opencl/CLContext.java b/src/com/jogamp/opencl/CLContext.java
index 3e6a72ed..a3157777 100644
--- a/src/com/mbien/opencl/CLContext.java
+++ b/src/com/jogamp/opencl/CLContext.java
@@ -1,9 +1,9 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
-import com.mbien.opencl.CLDevice.Type;
-import com.mbien.opencl.CLMemory.Mem;
-import com.mbien.opencl.CLSampler.AddressingMode;
-import com.mbien.opencl.CLSampler.FilteringMode;
+import com.jogamp.opencl.CLDevice.Type;
+import com.jogamp.opencl.CLMemory.Mem;
+import com.jogamp.opencl.CLSampler.AddressingMode;
+import com.jogamp.opencl.CLSampler.FilteringMode;
import com.jogamp.common.nio.Int64Buffer;
import com.jogamp.common.nio.PointerBuffer;
import java.io.BufferedReader;
@@ -24,7 +24,7 @@ import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
-import static com.mbien.opencl.CLException.*;
+import static com.jogamp.opencl.CLException.*;
import static com.jogamp.common.nio.Buffers.*;
import static com.jogamp.common.os.Platform.*;
@@ -423,7 +423,7 @@ public class CLContext extends CLObject implements CLResource {
* Returns the device with maximal FLOPS from this context.
* The device speed is estimated by calculating the product of
* MAX_COMPUTE_UNITS and MAX_CLOCK_FREQUENCY.
- * @see #getMaxFlopsDevice(com.mbien.opencl.CLDevice.Type)
+ * @see #getMaxFlopsDevice(com.jogamp.opencl.CLDevice.Type)
*/
public CLDevice getMaxFlopsDevice() {
return CLPlatform.findMaxFlopsDevice(getDevices());
diff --git a/src/com/mbien/opencl/CLDevice.java b/src/com/jogamp/opencl/CLDevice.java
index a85b2eb9..3b26e507 100644
--- a/src/com/mbien/opencl/CLDevice.java
+++ b/src/com/jogamp/opencl/CLDevice.java
@@ -1,6 +1,6 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
-import com.mbien.opencl.util.CLUtil;
+import com.jogamp.opencl.util.CLUtil;
import com.jogamp.common.nio.Int64Buffer;
import com.jogamp.common.os.Platform;
import java.nio.Buffer;
@@ -14,14 +14,14 @@ import java.util.Map;
import java.util.Scanner;
import java.util.Set;
-import static com.mbien.opencl.CL.*;
+import static com.jogamp.opencl.CL.*;
/**
* This object represents an OpenCL device.
- * @see CLPlatform#listCLDevices(com.mbien.opencl.CLDevice.Type...)
- * @see CLPlatform#getMaxFlopsDevice(com.mbien.opencl.CLDevice.Type...)
+ * @see CLPlatform#listCLDevices(com.jogamp.opencl.CLDevice.Type...)
+ * @see CLPlatform#getMaxFlopsDevice(com.jogamp.opencl.CLDevice.Type...)
* @see CLContext#getDevices()
- * @see CLContext#getMaxFlopsDevice(com.mbien.opencl.CLDevice.Type)
+ * @see CLContext#getMaxFlopsDevice(com.jogamp.opencl.CLDevice.Type)
* @author Michael Bien
*/
public final class CLDevice extends CLObject {
@@ -507,7 +507,7 @@ public final class CLDevice extends CLObject {
/**
* Returns a Map of device properties with the enum names as keys.
- * @see CLUtil#obtainDeviceProperties(com.mbien.opencl.CLDevice)
+ * @see CLUtil#obtainDeviceProperties(com.jogamp.opencl.CLDevice)
*/
public Map<String, String> getProperties() {
return CLUtil.obtainDeviceProperties(this);
diff --git a/src/com/mbien/opencl/CLEventList.java b/src/com/jogamp/opencl/CLEventList.java
index 928ce9bf..b9b4cd4b 100644
--- a/src/com/mbien/opencl/CLEventList.java
+++ b/src/com/jogamp/opencl/CLEventList.java
@@ -1,4 +1,4 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import com.jogamp.common.nio.PointerBuffer;
import java.util.Iterator;
diff --git a/src/com/mbien/opencl/CLException.java b/src/com/jogamp/opencl/CLException.java
index 63696a81..29491bc7 100644
--- a/src/com/mbien/opencl/CLException.java
+++ b/src/com/jogamp/opencl/CLException.java
@@ -1,6 +1,6 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
-import static com.mbien.opencl.CL.*;
+import static com.jogamp.opencl.CL.*;
/**
* Main Exception type for runtime OpenCL errors and failed function calls (e.g. returning not CL_SUCCESS).
diff --git a/src/com/mbien/opencl/CLImage.java b/src/com/jogamp/opencl/CLImage.java
index 2e201b4a..f8916fdb 100644
--- a/src/com/mbien/opencl/CLImage.java
+++ b/src/com/jogamp/opencl/CLImage.java
@@ -1,9 +1,9 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import com.jogamp.common.nio.Int64Buffer;
import java.nio.Buffer;
-import static com.mbien.opencl.CL.*;
+import static com.jogamp.opencl.CL.*;
/**
*
diff --git a/src/com/mbien/opencl/CLImage2d.java b/src/com/jogamp/opencl/CLImage2d.java
index c0d18dd3..7cf04cf1 100644
--- a/src/com/mbien/opencl/CLImage2d.java
+++ b/src/com/jogamp/opencl/CLImage2d.java
@@ -1,10 +1,10 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import com.jogamp.common.nio.Buffers;
import java.nio.Buffer;
import java.nio.IntBuffer;
-import static com.mbien.opencl.CLException.*;
+import static com.jogamp.opencl.CLException.*;
/**
*
diff --git a/src/com/mbien/opencl/CLImage3d.java b/src/com/jogamp/opencl/CLImage3d.java
index 6a01ffcc..fd127864 100644
--- a/src/com/mbien/opencl/CLImage3d.java
+++ b/src/com/jogamp/opencl/CLImage3d.java
@@ -1,11 +1,11 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import com.jogamp.common.nio.Buffers;
import java.nio.Buffer;
import java.nio.IntBuffer;
-import static com.mbien.opencl.CL.*;
-import static com.mbien.opencl.CLException.*;
+import static com.jogamp.opencl.CL.*;
+import static com.jogamp.opencl.CLException.*;
/**
*
diff --git a/src/com/mbien/opencl/CLImageFormat.java b/src/com/jogamp/opencl/CLImageFormat.java
index d2e452b8..20f2c4b1 100644
--- a/src/com/mbien/opencl/CLImageFormat.java
+++ b/src/com/jogamp/opencl/CLImageFormat.java
@@ -1,8 +1,8 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
-import com.mbien.opencl.impl.CLImageFormatImpl;
+import com.jogamp.opencl.impl.CLImageFormatImpl;
-import static com.mbien.opencl.CL.*;
+import static com.jogamp.opencl.CL.*;
/**
*
diff --git a/src/com/mbien/opencl/CLInfoAccessor.java b/src/com/jogamp/opencl/CLInfoAccessor.java
index 9f2ae1aa..56f2318d 100644
--- a/src/com/mbien/opencl/CLInfoAccessor.java
+++ b/src/com/jogamp/opencl/CLInfoAccessor.java
@@ -1,12 +1,12 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import com.jogamp.common.nio.Buffers;
import com.jogamp.common.nio.Int64Buffer;
-import com.mbien.opencl.util.CLUtil;
+import com.jogamp.opencl.util.CLUtil;
import java.nio.Buffer;
import java.nio.ByteBuffer;
-import static com.mbien.opencl.CLException.*;
+import static com.jogamp.opencl.CLException.*;
/**
* Internal utility for common OpenCL clGetFooInfo calls.
diff --git a/src/com/mbien/opencl/CLKernel.java b/src/com/jogamp/opencl/CLKernel.java
index a66e082c..ca7f6786 100644
--- a/src/com/mbien/opencl/CLKernel.java
+++ b/src/com/jogamp/opencl/CLKernel.java
@@ -1,6 +1,6 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
-import com.mbien.opencl.util.CLUtil;
+import com.jogamp.opencl.util.CLUtil;
import com.jogamp.common.nio.Buffers;
import com.jogamp.common.os.Platform;
import com.jogamp.common.nio.Int64Buffer;
@@ -8,8 +8,8 @@ import java.nio.Buffer;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
-import static com.mbien.opencl.CLException.*;
-import static com.mbien.opencl.CL.*;
+import static com.jogamp.opencl.CLException.*;
+import static com.jogamp.opencl.CL.*;
/**
* High level abstraction for an OpenCL Kernel.
diff --git a/src/com/mbien/opencl/CLObject.java b/src/com/jogamp/opencl/CLObject.java
index ff5f7d1f..58c8485c 100644
--- a/src/com/mbien/opencl/CLObject.java
+++ b/src/com/jogamp/opencl/CLObject.java
@@ -1,4 +1,4 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
/**
* Common superclass for all OpenCL objects.
diff --git a/src/com/mbien/opencl/CLPlatform.java b/src/com/jogamp/opencl/CLPlatform.java
index 545ca9f6..f3c00926 100644
--- a/src/com/mbien/opencl/CLPlatform.java
+++ b/src/com/jogamp/opencl/CLPlatform.java
@@ -1,8 +1,8 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import com.jogamp.common.nio.Int64Buffer;
-import com.mbien.opencl.util.CLUtil;
-import com.mbien.opencl.impl.CLImpl;
+import com.jogamp.opencl.util.CLUtil;
+import com.jogamp.opencl.impl.CLImpl;
import com.jogamp.common.nio.PointerBuffer;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
@@ -15,8 +15,8 @@ import java.util.Map;
import java.util.Scanner;
import java.util.Set;
-import static com.mbien.opencl.CLException.*;
-import static com.mbien.opencl.CL.*;
+import static com.jogamp.opencl.CLException.*;
+import static com.jogamp.opencl.CL.*;
/**
*
@@ -96,7 +96,7 @@ public final class CLPlatform {
/**
* Lists all physical devices available on this platform.
- * @see #listCLDevices(com.mbien.opencl.CLDevice.Type...)
+ * @see #listCLDevices(com.jogamp.opencl.CLDevice.Type...)
*/
public CLDevice[] listCLDevices() {
return this.listCLDevices(CLDevice.Type.ALL);
@@ -177,7 +177,7 @@ public final class CLPlatform {
* Returns the device with maximal FLOPS from this platform.
* The device speed is estimated by calculating the product of
* MAX_COMPUTE_UNITS and MAX_CLOCK_FREQUENCY.
- * @see #getMaxFlopsDevice(com.mbien.opencl.CLDevice.Type...)
+ * @see #getMaxFlopsDevice(com.jogamp.opencl.CLDevice.Type...)
*/
public CLDevice getMaxFlopsDevice() {
return findMaxFlopsDevice(listCLDevices());
@@ -248,7 +248,7 @@ public final class CLPlatform {
/**
* Returns a Map of platform properties with the enum names as keys.
- * @see CLUtil#obtainPlatformProperties(com.mbien.opencl.CLPlatform)
+ * @see CLUtil#obtainPlatformProperties(com.jogamp.opencl.CLPlatform)
*/
public Map<String, String> getProperties() {
return CLUtil.obtainPlatformProperties(this);
diff --git a/src/com/mbien/opencl/CLProgram.java b/src/com/jogamp/opencl/CLProgram.java
index db0b7304..bb5abccf 100644
--- a/src/com/mbien/opencl/CLProgram.java
+++ b/src/com/jogamp/opencl/CLProgram.java
@@ -1,7 +1,7 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
-import com.mbien.opencl.util.CLProgramConfiguration;
-import com.mbien.opencl.util.CLUtil;
+import com.jogamp.opencl.util.CLProgramConfiguration;
+import com.jogamp.opencl.util.CLUtil;
import com.jogamp.common.nio.Int64Buffer;
import com.jogamp.common.os.Platform;
import com.jogamp.common.nio.PointerBuffer;
@@ -14,8 +14,8 @@ import java.util.LinkedHashMap;
import java.util.Set;
import java.util.Map;
-import static com.mbien.opencl.CLException.*;
-import static com.mbien.opencl.CL.*;
+import static com.jogamp.opencl.CLException.*;
+import static com.jogamp.opencl.CL.*;
import static com.jogamp.common.nio.Buffers.*;
/**
diff --git a/src/com/mbien/opencl/CLProgramBuilder.java b/src/com/jogamp/opencl/CLProgramBuilder.java
index 7071d142..855d9837 100644
--- a/src/com/mbien/opencl/CLProgramBuilder.java
+++ b/src/com/jogamp/opencl/CLProgramBuilder.java
@@ -1,7 +1,7 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
-import com.mbien.opencl.util.CLBuildConfiguration;
-import com.mbien.opencl.util.CLProgramConfiguration;
+import com.jogamp.opencl.util.CLBuildConfiguration;
+import com.jogamp.opencl.util.CLProgramConfiguration;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
@@ -21,9 +21,9 @@ import java.util.Set;
* building multiple programs with similar configurations.
* @see CLProgram#prepare()
* @see #createConfiguration()
- * @see #createConfiguration(com.mbien.opencl.CLProgram)
+ * @see #createConfiguration(com.jogamp.opencl.CLProgram)
* @see #loadConfiguration(java.io.ObjectInputStream)
- * @see #loadConfiguration(java.io.ObjectInputStream, com.mbien.opencl.CLContext)
+ * @see #loadConfiguration(java.io.ObjectInputStream, com.jogamp.opencl.CLContext)
* @author Michael Bien
*/
public final class CLProgramBuilder implements CLProgramConfiguration, Serializable {
diff --git a/src/com/mbien/opencl/CLResource.java b/src/com/jogamp/opencl/CLResource.java
index 8996b40e..63b4749e 100644
--- a/src/com/mbien/opencl/CLResource.java
+++ b/src/com/jogamp/opencl/CLResource.java
@@ -1,4 +1,4 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
/**
* Releasable OpenCL resource.
diff --git a/src/com/mbien/opencl/CLSampler.java b/src/com/jogamp/opencl/CLSampler.java
index 397639c9..79ef6067 100644
--- a/src/com/mbien/opencl/CLSampler.java
+++ b/src/com/jogamp/opencl/CLSampler.java
@@ -1,16 +1,16 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import com.jogamp.common.nio.Int64Buffer;
-import com.jogamp.common.nio.PointerBuffer;
+
import java.nio.Buffer;
-import static com.mbien.opencl.CLException.*;
-import static com.mbien.opencl.CL.*;
-import static com.mbien.opencl.util.CLUtil.*;
+import static com.jogamp.opencl.CLException.*;
+import static com.jogamp.opencl.CL.*;
+import static com.jogamp.opencl.util.CLUtil.*;
/**
* Object representing an OpenCL sampler.
- * @see CLContext#createSampler(com.mbien.opencl.CLSampler.AddressingMode, com.mbien.opencl.CLSampler.FilteringMode, boolean)
+ * @see CLContext#createSampler(com.jogamp.opencl.CLSampler.AddressingMode, com.jogamp.opencl.CLSampler.FilteringMode, boolean)
* @author Michael Bien
*/
public class CLSampler extends CLObject implements CLResource {
diff --git a/src/com/mbien/opencl/CreateContextCallback.java b/src/com/jogamp/opencl/CreateContextCallback.java
index e965370c..dc25860a 100644
--- a/src/com/mbien/opencl/CreateContextCallback.java
+++ b/src/com/jogamp/opencl/CreateContextCallback.java
@@ -1,4 +1,4 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import java.nio.ByteBuffer;
diff --git a/src/com/mbien/opencl/Disposable.java b/src/com/jogamp/opencl/Disposable.java
index f85f99b6..2cd1784b 100644
--- a/src/com/mbien/opencl/Disposable.java
+++ b/src/com/jogamp/opencl/Disposable.java
@@ -1,4 +1,4 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
/*
* JDK7 ARM proposal, cypied to be forward compatible with java 7 automatic resource managment blocks.
diff --git a/src/com/mbien/opencl/InternalBufferUtil.java b/src/com/jogamp/opencl/InternalBufferUtil.java
index a2573784..9cd1fac9 100644
--- a/src/com/mbien/opencl/InternalBufferUtil.java
+++ b/src/com/jogamp/opencl/InternalBufferUtil.java
@@ -1,4 +1,4 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import java.lang.reflect.Field;
import java.nio.Buffer;
diff --git a/src/com/mbien/opencl/NativeLibLoader.java b/src/com/jogamp/opencl/NativeLibLoader.java
index c0f0fe81..67824b95 100644
--- a/src/com/mbien/opencl/NativeLibLoader.java
+++ b/src/com/jogamp/opencl/NativeLibLoader.java
@@ -1,4 +1,4 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import java.security.AccessController;
import java.security.PrivilegedAction;
diff --git a/src/com/mbien/opencl/gl/CLGLBuffer.java b/src/com/jogamp/opencl/gl/CLGLBuffer.java
index 97a25626..c7f14c4c 100644
--- a/src/com/mbien/opencl/gl/CLGLBuffer.java
+++ b/src/com/jogamp/opencl/gl/CLGLBuffer.java
@@ -1,9 +1,9 @@
-package com.mbien.opencl.gl;
+package com.jogamp.opencl.gl;
+
+import com.jogamp.opencl.CL;
+import com.jogamp.opencl.CLBuffer;
+import com.jogamp.opencl.CLContext;
-import com.mbien.opencl.CL;
-import com.mbien.opencl.CLBuffer;
-import com.mbien.opencl.CLContext;
-import com.mbien.opencl.CLMemory.GLObjectType;
import java.nio.Buffer;
import javax.media.opengl.GLContext;
diff --git a/src/com/mbien/opencl/gl/CLGLContext.java b/src/com/jogamp/opencl/gl/CLGLContext.java
index db9d6150..92618729 100644
--- a/src/com/mbien/opencl/gl/CLGLContext.java
+++ b/src/com/jogamp/opencl/gl/CLGLContext.java
@@ -1,10 +1,10 @@
-package com.mbien.opencl.gl;
+package com.jogamp.opencl.gl;
-import com.mbien.opencl.CLContext;
-import com.mbien.opencl.CLDevice;
+import com.jogamp.opencl.CLContext;
+import com.jogamp.opencl.CLDevice;
import java.nio.Buffer;
-import com.mbien.opencl.CLMemory.Mem;
-import com.mbien.opencl.CLPlatform;
+import com.jogamp.opencl.CLMemory.Mem;
+import com.jogamp.opencl.CLPlatform;
import com.jogamp.common.nio.PointerBuffer;
import com.jogamp.opengl.impl.GLContextImpl;
import com.jogamp.opengl.impl.macosx.cgl.MacOSXCGLContext;
@@ -13,7 +13,7 @@ import com.jogamp.opengl.impl.x11.glx.X11GLXContext;
import javax.media.nativewindow.DefaultGraphicsConfiguration;
import javax.media.opengl.GLContext;
-import static com.mbien.opencl.gl.CLGLI.*;
+import static com.jogamp.opencl.gl.CLGLI.*;
/**
* OpenCL Context supporting JOGL-JOCL interoperablity.
diff --git a/src/com/mbien/opencl/gl/CLGLImage2d.java b/src/com/jogamp/opencl/gl/CLGLImage2d.java
index 853c057e..82021816 100644
--- a/src/com/mbien/opencl/gl/CLGLImage2d.java
+++ b/src/com/jogamp/opencl/gl/CLGLImage2d.java
@@ -1,15 +1,14 @@
-package com.mbien.opencl.gl;
-
-import com.mbien.opencl.CL;
-import com.mbien.opencl.CLContext;
-import com.mbien.opencl.CLImage2d;
-import com.mbien.opencl.CLImageFormat;
-import com.mbien.opencl.CLMemory.GLObjectType;
-import com.mbien.opencl.impl.CLImageFormatImpl;
+package com.jogamp.opencl.gl;
+
+import com.jogamp.opencl.CL;
+import com.jogamp.opencl.CLContext;
+import com.jogamp.opencl.CLImage2d;
+import com.jogamp.opencl.CLImageFormat;
+import com.jogamp.opencl.impl.CLImageFormatImpl;
import java.nio.Buffer;
import javax.media.opengl.GLContext;
-import static com.mbien.opencl.CL.*;
+import static com.jogamp.opencl.CL.*;
/**
* 2D OpenCL image representing an OpenGL renderbuffer.
diff --git a/src/com/mbien/opencl/gl/CLGLObject.java b/src/com/jogamp/opencl/gl/CLGLObject.java
index 84c3ecef..6e2aa9d2 100644
--- a/src/com/mbien/opencl/gl/CLGLObject.java
+++ b/src/com/jogamp/opencl/gl/CLGLObject.java
@@ -1,9 +1,9 @@
/*
* Created on Friday, February 26 2010
*/
-package com.mbien.opencl.gl;
+package com.jogamp.opencl.gl;
-import com.mbien.opencl.CLMemory.GLObjectType;
+import com.jogamp.opencl.CLMemory.GLObjectType;
import javax.media.opengl.GLContext;
/**
diff --git a/src/com/mbien/opencl/gl/CLGLTexture.java b/src/com/jogamp/opencl/gl/CLGLTexture.java
index 246f7d06..312df80b 100644
--- a/src/com/mbien/opencl/gl/CLGLTexture.java
+++ b/src/com/jogamp/opencl/gl/CLGLTexture.java
@@ -2,7 +2,7 @@
* Created on Friday, February 26 2010
*/
-package com.mbien.opencl.gl;
+package com.jogamp.opencl.gl;
/**
*
diff --git a/src/com/mbien/opencl/gl/CLGLTexture2d.java b/src/com/jogamp/opencl/gl/CLGLTexture2d.java
index 37c9a28a..88b32286 100644
--- a/src/com/mbien/opencl/gl/CLGLTexture2d.java
+++ b/src/com/jogamp/opencl/gl/CLGLTexture2d.java
@@ -1,14 +1,12 @@
-package com.mbien.opencl.gl;
+package com.jogamp.opencl.gl;
-import com.mbien.opencl.CL;
-import com.mbien.opencl.CLContext;
-import com.mbien.opencl.CLImageFormat;
-import com.mbien.opencl.CLMemory.GLObjectType;
-import com.mbien.opencl.impl.CLImageFormatImpl;
+import com.jogamp.opencl.CL;
+import com.jogamp.opencl.CLContext;
+import com.jogamp.opencl.CLImageFormat;
+import com.jogamp.opencl.impl.CLImageFormatImpl;
import java.nio.Buffer;
-import javax.media.opengl.GLContext;
-import static com.mbien.opencl.CL.*;
+import static com.jogamp.opencl.CL.*;
/**
* 2D OpenCL image representing an 2D OpenGL texture.
diff --git a/src/com/mbien/opencl/gl/CLGLTexture3d.java b/src/com/jogamp/opencl/gl/CLGLTexture3d.java
index 0a25c890..8731b5e7 100644
--- a/src/com/mbien/opencl/gl/CLGLTexture3d.java
+++ b/src/com/jogamp/opencl/gl/CLGLTexture3d.java
@@ -1,15 +1,14 @@
-package com.mbien.opencl.gl;
-
-import com.mbien.opencl.CL;
-import com.mbien.opencl.CLContext;
-import com.mbien.opencl.CLImage3d;
-import com.mbien.opencl.CLImageFormat;
-import com.mbien.opencl.CLMemory.GLObjectType;
-import com.mbien.opencl.impl.CLImageFormatImpl;
+package com.jogamp.opencl.gl;
+
+import com.jogamp.opencl.CL;
+import com.jogamp.opencl.CLContext;
+import com.jogamp.opencl.CLImage3d;
+import com.jogamp.opencl.CLImageFormat;
+import com.jogamp.opencl.impl.CLImageFormatImpl;
import java.nio.Buffer;
import javax.media.opengl.GLContext;
-import static com.mbien.opencl.CL.*;
+import static com.jogamp.opencl.CL.*;
/**
* 3D OpenCL image representing an 3D OpenGL texture.
diff --git a/src/com/mbien/opencl/util/CLBuildConfiguration.java b/src/com/jogamp/opencl/util/CLBuildConfiguration.java
index a4d85b60..1de62637 100644
--- a/src/com/mbien/opencl/util/CLBuildConfiguration.java
+++ b/src/com/jogamp/opencl/util/CLBuildConfiguration.java
@@ -1,7 +1,7 @@
-package com.mbien.opencl.util;
+package com.jogamp.opencl.util;
-import com.mbien.opencl.CLDevice;
-import com.mbien.opencl.CLProgram;
+import com.jogamp.opencl.CLDevice;
+import com.jogamp.opencl.CLProgram;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.util.Map;
@@ -9,8 +9,8 @@ import java.util.Map;
/**
* Configuration representing everything needed to build an OpenCL program.
* @author Michael Bien
- * @see com.mbien.opencl.CLProgramBuilder#createConfiguration()
- * @see com.mbien.opencl.CLProgramBuilder#loadConfiguration(java.io.ObjectInputStream)
+ * @see com.jogamp.opencl.CLProgramBuilder#createConfiguration()
+ * @see com.jogamp.opencl.CLProgramBuilder#loadConfiguration(java.io.ObjectInputStream)
*/
public interface CLBuildConfiguration extends Cloneable {
@@ -69,25 +69,25 @@ public interface CLBuildConfiguration extends Cloneable {
/**
* Adds the definitions to the build configuration.
- * @see com.mbien.opencl.CLProgram#define(java.lang.String)
+ * @see com.jogamp.opencl.CLProgram#define(java.lang.String)
*/
public CLBuildConfiguration withDefines(String... names);
/**
* Adds the definitions to the build configuration.
- * @see com.mbien.opencl.CLProgram#define(java.lang.String, java.lang.Object)
+ * @see com.jogamp.opencl.CLProgram#define(java.lang.String, java.lang.Object)
*/
public CLBuildConfiguration withDefines(Map<String, ? extends Object> defines);
/**
* Adds the compiler option to the build configuration.
- * @see com.mbien.opencl.CLProgram.CompilerOptions
+ * @see com.jogamp.opencl.CLProgram.CompilerOptions
*/
public CLBuildConfiguration withOption(String option);
/**
* Adds the compiler options to the build configuration.
- * @see com.mbien.opencl.CLProgram.CompilerOptions
+ * @see com.jogamp.opencl.CLProgram.CompilerOptions
*/
public CLBuildConfiguration withOptions(String... options);
diff --git a/src/com/mbien/opencl/util/CLUtil.java b/src/com/jogamp/opencl/util/CLUtil.java
index 2b47ac84..6649698c 100644
--- a/src/com/mbien/opencl/util/CLUtil.java
+++ b/src/com/jogamp/opencl/util/CLUtil.java
@@ -1,8 +1,8 @@
-package com.mbien.opencl.util;
+package com.jogamp.opencl.util;
-import com.mbien.opencl.CL;
-import com.mbien.opencl.CLDevice;
-import com.mbien.opencl.CLPlatform;
+import com.jogamp.opencl.CL;
+import com.jogamp.opencl.CLDevice;
+import com.jogamp.opencl.CLPlatform;
import java.nio.ByteBuffer;
import java.util.Arrays;
import java.util.LinkedHashMap;
diff --git a/src/com/mbien/opencl/util/MultiQueueBarrier.java b/src/com/jogamp/opencl/util/MultiQueueBarrier.java
index 7ac45f6a..59398b5e 100644
--- a/src/com/mbien/opencl/util/MultiQueueBarrier.java
+++ b/src/com/jogamp/opencl/util/MultiQueueBarrier.java
@@ -1,7 +1,7 @@
-package com.mbien.opencl.util;
+package com.jogamp.opencl.util;
-import com.mbien.opencl.CLCommandQueue;
-import com.mbien.opencl.CLEventList;
+import com.jogamp.opencl.CLCommandQueue;
+import com.jogamp.opencl.CLEventList;
import java.util.Collections;
import java.util.HashSet;
import java.util.Set;
diff --git a/src/com/mbien/opencl/CLCommandQueue.java b/src/com/jogamp/opencl/CLCommandQueue.java
index ebb37dcf..1781a8ae 100644
--- a/src/com/mbien/opencl/CLCommandQueue.java
+++ b/src/com/jogamp/opencl/CLCommandQueue.java
@@ -1,7 +1,7 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import com.jogamp.common.nio.Int64Buffer;
-import com.mbien.opencl.gl.CLGLI;
+import com.jogamp.opencl.gl.CLGLI;
import com.jogamp.common.nio.PointerBuffer;
import java.nio.ByteBuffer;
import java.nio.IntBuffer;
@@ -10,9 +10,9 @@ import java.util.Arrays;
import java.util.EnumSet;
import java.util.List;
-import static com.mbien.opencl.CLException.*;
-import static com.mbien.opencl.CL.*;
-import static com.mbien.opencl.util.CLUtil.*;
+import static com.jogamp.opencl.CLException.*;
+import static com.jogamp.opencl.CL.*;
+import static com.jogamp.opencl.util.CLUtil.*;
/**
* The command queue is used to queue a set of operations for a specific {@link CLDevice}.
@@ -21,7 +21,7 @@ import static com.mbien.opencl.util.CLUtil.*;
* not being shared.<br/>
* Sharing of objects across multiple queues or using a CLCommandQueue
* form multiple Threads will require the application to perform appropriate synchronization.
- * @see CLDevice#createCommandQueue(com.mbien.opencl.CLCommandQueue.Mode...)
+ * @see CLDevice#createCommandQueue(com.jogamp.opencl.CLCommandQueue.Mode...)
* @author Michael Bien
*/
public class CLCommandQueue extends CLObject implements CLResource {
@@ -1121,7 +1121,7 @@ public class CLCommandQueue extends CLObject implements CLResource {
/**
* <p>Calls {@native clEnqueueTask}.</p>
- * @see #putTask(com.mbien.opencl.CLKernel)
+ * @see #putTask(com.jogamp.opencl.CLKernel)
*/
public CLCommandQueue putTask(CLKernel kernel, CLEventList events) {
putTask(kernel, null, events);
@@ -1130,7 +1130,7 @@ public class CLCommandQueue extends CLObject implements CLResource {
/**
* Calls {@native clEnqueueTask}.
- * @see #putTask(com.mbien.opencl.CLKernel)
+ * @see #putTask(com.jogamp.opencl.CLKernel)
*/
public CLCommandQueue putTask(CLKernel kernel, CLEventList condition, CLEventList events) {
@@ -1545,7 +1545,7 @@ public class CLCommandQueue extends CLObject implements CLResource {
/**
* Enables profiling of commands in the command-queue.
* If set, the profiling of commands is enabled. Otherwise profiling of
* commands is disabled. See {@link com.mbien.opencl.CLEvent} for more information.
*/
PROFILING_MODE(CL_QUEUE_PROFILING_ENABLE);
@@ -1545,7 +1545,7 @@ public class CLCommandQueue extends CLObject implements CLResource {
* Enables profiling of commands in the command-queue.
* If set, the profiling of commands is enabled. Otherwise profiling of
- * commands is disabled. See {@link com.mbien.opencl.CLEvent} for more information.
+ * commands is disabled. See {@link com.jogamp.opencl.CLEvent} for more information.
*/
PROFILING_MODE(CL_QUEUE_PROFILING_ENABLE);
diff --git a/src/com/mbien/opencl/CLEvent.java b/src/com/jogamp/opencl/CLEvent.java
index bbcf74cb..46b92a6d 100644
--- a/src/com/mbien/opencl/CLEvent.java
+++ b/src/com/jogamp/opencl/CLEvent.java
@@ -1,17 +1,17 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
import com.jogamp.common.nio.Int64Buffer;
import java.nio.Buffer;
-import static com.mbien.opencl.CL.*;
-import static com.mbien.opencl.CLException.*;
+import static com.jogamp.opencl.CL.*;
+import static com.jogamp.opencl.CLException.*;
/**
* Event objects can be used for synchronizing command queues, e.g you can wait until a
* event occurs or they can also be used to capture profiling information that
* measure execution time of a command.
* Profiling of OpenCL commands can be enabled by using a {@link com.mbien.opencl.CLCommandQueue} created with
* {@link com.mbien.opencl.CLCommandQueue.Mode#PROFILING_MODE}.
* @author Michael Bien
*/
public class CLEvent extends CLObject implements CLResource {
@@ -1,17 +1,17 @@
* event occurs or they can also be used to capture profiling information that
* measure execution time of a command.
- * Profiling of OpenCL commands can be enabled by using a {@link com.mbien.opencl.CLCommandQueue} created with
- * {@link com.mbien.opencl.CLCommandQueue.Mode#PROFILING_MODE}.
+ * Profiling of OpenCL commands can be enabled by using a {@link com.jogamp.opencl.CLCommandQueue} created with
+ * {@link com.jogamp.opencl.CLCommandQueue.Mode#PROFILING_MODE}.
* @author Michael Bien
*/
diff --git a/src/com/mbien/opencl/CLMemory.java b/src/com/jogamp/opencl/CLMemory.java
index 3c3b1531..55a04af9 100644
--- a/src/com/mbien/opencl/CLMemory.java
+++ b/src/com/jogamp/opencl/CLMemory.java
@@ -1,6 +1,6 @@
-package com.mbien.opencl;
+package com.jogamp.opencl;
-import com.mbien.opencl.gl.CLGLI;
+import com.jogamp.opencl.gl.CLGLI;
import com.jogamp.common.nio.Buffers;
import com.jogamp.common.nio.PointerBuffer;
import java.nio.Buffer;
@@ -13,8 +13,8 @@ import java.util.ArrayList;
import java.util.EnumSet;
import java.util.List;
-import static com.mbien.opencl.CLException.*;
-import static com.mbien.opencl.gl.CLGLI.*;
+import static com.jogamp.opencl.CLException.*;
+import static com.jogamp.opencl.gl.CLGLI.*;
/**
* Common superclass for all OpenCL memory types.
@@ -318,9 +318,9 @@ public abstract class CLMemory <B extends Buffer> extends CLObject implements CL
/**
* Configures the mapping process.
* @see com.mbien.opencl.CLCommandQueue#putMapBuffer(CLBuffer, com.mbien.opencl.CLMemory.Map, boolean).
* @see com.mbien.opencl.CLCommandQueue#putMapImage(CLImage2d, com.mbien.opencl.CLMemory.Map, boolean)
* @see com.mbien.opencl.CLCommandQueue#putMapImage(CLImage3d, com.mbien.opencl.CLMemory.Map, boolean)
*/
public enum Map {
@@ -318,9 +318,9 @@ public abstract class CLMemory <B extends Buffer> extends CLObject implements CL
/**
* Configures the mapping process.
- * @see com.mbien.opencl.CLCommandQueue#putMapBuffer(CLBuffer, com.mbien.opencl.CLMemory.Map, boolean).
- * @see com.mbien.opencl.CLCommandQueue#putMapImage(CLImage2d, com.mbien.opencl.CLMemory.Map, boolean)
- * @see com.mbien.opencl.CLCommandQueue#putMapImage(CLImage3d, com.mbien.opencl.CLMemory.Map, boolean)
+ * @see com.jogamp.opencl.CLCommandQueue#putMapBuffer(CLBuffer, com.jogamp.opencl.CLMemory.Map, boolean).
+ * @see com.jogamp.opencl.CLCommandQueue#putMapImage(CLImage2d, com.jogamp.opencl.CLMemory.Map, boolean)
+ * @see com.jogamp.opencl.CLCommandQueue#putMapImage(CLImage3d, com.jogamp.opencl.CLMemory.Map, boolean)
*/
public enum Map {
diff --git a/src/com/mbien/opencl/util/CLProgramConfiguration.java b/src/com/jogamp/opencl/util/CLProgramConfiguration.java
index 105a4b72..901e28ce 100644
--- a/src/com/mbien/opencl/util/CLProgramConfiguration.java
+++ b/src/com/jogamp/opencl/util/CLProgramConfiguration.java
@@ -1,7 +1,7 @@
-package com.mbien.opencl.util;
+package com.jogamp.opencl.util;
-import com.mbien.opencl.CLDevice;
-import com.mbien.opencl.CLProgram;
+import com.jogamp.opencl.CLDevice;
+import com.jogamp.opencl.CLProgram;
import java.util.Map;
/**
@@ -9,8 +9,8 @@ import java.util.Map;
* CLProgramConfiguration is a helper for building programs with more complex configurations or
* building multiple programs with the similar configuration.
* @see CLProgram#prepare()
* @see com.mbien.opencl.CLProgramBuilder#createConfiguration(com.mbien.opencl.CLProgram)
* @see com.mbien.opencl.CLProgramBuilder#loadConfiguration(java.io.ObjectInputStream, com.mbien.opencl.CLContext)
* @author Michael Bien
*/
public interface CLProgramConfiguration extends CLBuildConfiguration {
@@ -9,8 +9,8 @@ import java.util.Map;
* building multiple programs with the similar configuration.
* @see CLProgram#prepare()
- * @see com.mbien.opencl.CLProgramBuilder#createConfiguration(com.mbien.opencl.CLProgram)
- * @see com.mbien.opencl.CLProgramBuilder#loadConfiguration(java.io.ObjectInputStream, com.mbien.opencl.CLContext)
+ * @see com.jogamp.opencl.CLProgramBuilder#createConfiguration(com.jogamp.opencl.CLProgram)
+ * @see com.jogamp.opencl.CLProgramBuilder#loadConfiguration(java.io.ObjectInputStream, com.jogamp.opencl.CLContext)
* @author Michael Bien
*/